@@ -1,7 +1,7 @@
 # need d as global because data=d in function def does not
 #  have a value assigned to d, d <- mydata does do that, even if conditional
 #  generates a Note
-if (getRversion() >= "3.5.0")
+if (getRversion() >= "3.6.0")
   globalVariables(c("d", "mydata", "l", "mylabels", "mycor"))
 
 
@@ -9,7 +9,7 @@ if (getRversion() >= "3.5.0")
 function(...) {
 
   packageStartupMessage("\n",
-      "lessR 4.2.5                         feedback: gerbing@pdx.edu \n",
+      "lessR 4.2.6                         feedback: gerbing@pdx.edu \n",
       "--------------------------------------------------------------\n",
       "> d <- Read(\"\")   Read text, Excel, SPSS, SAS, or R data file\n",
       "  d is default data frame, data= in analysis routines optional\n",
@@ -80,7 +80,8 @@ function(...) {
   options(lab_color = "gray15")
   options(lab_x_color = NULL)
   options(lab_y_color = NULL)
-  options(lab_cex = .88)
+  lcx <- ifelse (options("device")=="RStudioGD", .88, .60)
+  options(lab_cex = lcx)
   options(lab_x_cex = NULL)
   options(lab_y_cex = NULL)
 
@@ -93,7 +94,8 @@ function(...) {
   options(axis_lty = "solid")
   options(axis_x_lty = NULL)
   options(axis_y_lty = NULL)
-  options(axis_cex = 0.75)
+  acx <- ifelse (options("device")=="RStudioGD", .75, .50)
+  options(axis_cex = acx)
   options(axis_x_cex = NULL)
   options(axis_y_cex = NULL)
   options(axis_text_color = "gray20")
@@ -142,6 +144,7 @@ function(...) {
   options(scipen = 30)
 
   options(mc_doScale_quiet=TRUE)  # for mc() function in robustbase
+
 }
 
 
@@ -746,7 +749,6 @@ function(...) {
 
 
 .title2 <- function(x.name, y.name, x.lbl, y.lbl, isnullby, new.ln=FALSE) {
-
   txt1 <- x.name
   if (!is.null(x.lbl)) txt1 <- paste(txt1, ": ", x.lbl, sep="")
 
@@ -959,7 +961,7 @@ function(lab, labcex, cut, nm, var.nm, units) {
   n.lab_ln <- (strw %/% cut) + 1
   if (n.lab_ln < 1) {
     cat("\n"); stop(call.=FALSE, "\n","------\n",
-      "No room for axis labels, readjust.\n\n")
+      "No room for axis labels, increase the size of the plot window.\n\n")
   }
 
   if (strw > cut) {
@@ -1491,19 +1493,22 @@ function(lab, labcex, cut, nm, var.nm, units) {
 # if not a palette name, then return the name, i.e., do nothing
 # typically used to convert color name from get_fill() to a color
 .color_range <- function(fill, n.clr) {
+  if (fill[1] == "magma") fill[1] <- "plasma"
 
   # names of color palettes generated by getColors
-  nm <- c("reds", "rusts", "browns", "olives", "greens", "emeralds",
+  nmC <- c("reds", "rusts", "browns", "olives", "greens", "emeralds",
           "turquoises", "aquas", "blues", "purples", "violets", "magentas",
           "grays", "hues")
   nmR <- c("rainbow", "heat", "terrain")
-  nmV<- c("viridis", "cividis", "magma", "inferno", "plasma")
+  nmV<- c("viridis", "cividis", "plasma", "spectral")
+  nmO<- c("Okabe-Ito")
   nmD<- c("distinct")
   nmW<- c("BottleRocket1", "BottleRocket2", "Rushmore1",
           "Royal1", "Royal2", "Zissou1", "Darjeeling1", "Darjeeling2",
           "Chevalier1", "FantasticFox1", "Moonrise1", "Moonrise2",
           "Moonrise3", "Cavalcanti1", "GrandBudapest1", "GrandBudapest2",
           "IsleofDogs1", "IsleofDogs2")
+  nm <- c(nmC, nmR, nmV, nmO, nmD, nmW)
 
   # fill is a function such as hcl or is a named vector
   if (is.call(fill) || is.name(fill)) {
@@ -1516,13 +1521,10 @@ function(lab, labcex, cut, nm, var.nm, units) {
       if (fill[1] == "colors") fill[1] <- "hues"   # new names
       if (fill[1] == "yellows")  fill[1] <- "browns"
 
-      if (fill[1] %in% nm  ||  fill[1] %in% nmR  ||  fill[1] %in% nmV  ||
-          fill[1] %in% nmW  ||  fill[1] %in% nmD) {
+      if (fill[1] %in% nm)
         clrs <- getColors(fill[1], n=n.clr, output=FALSE)  # sequential palette
-      }
-      else {
+      else 
         clrs <- fill  # not an identified name of a color range
-      }
 
       if (length(fill == 2)) {  # divergent
         if (fill[2] %in% nm)
@@ -1576,19 +1578,6 @@ function(lab, labcex, cut, nm, var.nm, units) {
     clr <- cc
   }
 
-  else {  # (count.v) so do viridis scaling
-    if (!requireNamespace("viridisLite", quietly=TRUE)) {
-      stop("Package \"viridisLite\" needed for these colors\n",
-           "Please install it:  install.packages(\"viridisLite\")\n\n",
-           call. = FALSE)
-    }
-    vir <- viridisLite::viridis(100)
-    x.nrm <- x / max(x)
-    cc <- double(length=length(x.nrm))
-    for (i in 1:length(cc)) cc[i] <-  viridisLite::viridis(1, begin=x.nrm[i])
-    clr <- cc
-  }
-
   return(clr)
 
 }
